@@ -63,57 +63,32 @@ def create_float_zeros_as_CFFI_double( n):
     return x, px
 
 def convert_py_float_to_cffi( x):
-    if isinstance( x, np.ndarray) == True:
-        px = np.ascontiguousarray( x, dtype = 'float64')
-    else:
-        if x != None:
-            px = np.ascontiguousarray( x, dtype = 'float64')
+    if x is not None:
+        if isinstance( x, np.ndarray) and ( x.flags.c_contiguous == True) and ( x.dtype == np.float64):
+            px = x
         else:
-            # handle None
-           px = np.array( 0.0)        
-    pxcffi = ffi.cast( "double *", px.ctypes.data)
+            px =  np.ascontiguousarray( x, dtype = 'float64')
+        pxcffi = ffi.cast( "double *", px.ctypes.data)
+    else:
+        # handle None
+        px = np.array( 0)
+        pxcffi = ffi.cast( "double *", 0)
     return px, pxcffi
 
 
 def convert_py_int_to_cffi( x):
-    if isinstance( x, np.ndarray) == True:
-        px = np.ascontiguousarray( x, dtype = 'int32')
-    else:
-        if x != None:
-            px = np.ascontiguousarray( x, dtype = 'int32')
+    if x is not None:
+        if isinstance( x, np.ndarray) and ( x.flags.c_contiguous == True) and ( x.dtype == np.int32):
+            px = x
         else:
-            # handle None
-           px = np.array( 0)        
-    pxcffi = ffi.cast( "int *", px.ctypes.data)
+            px =  np.ascontiguousarray( x, dtype = 'int32')
+        pxcffi = ffi.cast( "int *", px.ctypes.data)
+    else:
+        # handle None
+        px = np.array( 0)
+        pxcffi = ffi.cast( "int *", 0)
     return px, pxcffi
 
-# def convert_py_float_to_cffi( x):
-#     if isinstance( x, np.ndarray) or x != None:
-#         if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.float64):
-#             px = np.ascontiguousarray( x, dtype = 'float64')
-#         else:
-#             px = x
-#     else: 
-#         # handle None
-#         px = np.array( 0.0)
-    
-#     pxcffi = ffi.cast( "double *", px.ctypes.data)
-#     return px, pxcffi
-
-# def convert_py_int_to_cffi( x):
-#     if isinstance( x, np.ndarray) or x != None:
-#         if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.int32):
-#             px = np.ascontiguousarray( x, dtype = 'int32')
-#             pxcffi = ffi.cast( "int *", px.ctypes.data)
-#         else:
-#             px = x
-#     else: 
-#         # handle None
-#         px = np.array( 0)
-#         pxcffi = ffi.cast( "int *", 0)
-        
-#     return px, pxcffi
-
 ###
 # Python wrapper classes 
 ###
@@ -383,6 +358,23 @@ def STCValue( x, id = 0):
     
     return fm.STCValue( id, px)
 
+# New wrapper function returning a list of predictions 
+# This avoids multiple calls to np.ascontiguousarray()
+# Next step: to impeove performance implement the loop in C++ 
+def LipIntValues( n, Dim, Ndata, x, Xd, y, Lipconst, Index, id = 0):
+    trace( "double	LipIntValues(int n, int* Dim, int* Ndata, double* x, double* Xd,double* y,  double* Lipconst, int* Index)")
+    pDimnp, pDim = convert_py_int_to_cffi( Dim)
+    pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
+    pxnp, px = convert_py_float_to_cffi( x)
+    pXdnp, pXd = convert_py_float_to_cffi( Xd)
+    pynp, py = convert_py_float_to_cffi( y)
+    pLipconstnp, pLipconst = convert_py_float_to_cffi( Lipconst)
+    pIndexnp, pIndex = convert_py_int_to_cffi( Index)
+
+    pred = [ fm.LipIntValue( id, pDim, pNdata, px[i,:], pXd, py, pLipconst, pIndex) for i in range( 0, n)]
+    return pred
+
+
 ###
 # Remaining wrapper functions 
 ###
