@@ -3,6 +3,7 @@ import sys
 import math
 import random
 import time
+from memory_profiler import profile 
 
 # Trace function
 def trace( str):
@@ -128,6 +129,7 @@ def initial_test_class():
 ###
 # example of usage of SLipInt
 ###
+@profile
 def test_slip_int():
     trace( 'example of usage of SLipInt: start')
 
@@ -138,7 +140,8 @@ def test_slip_int():
 
     for j in range( dim): x[j]=random.random() * 3.0 # some random x
     # calculate the value
-    index = [0] * npts
+    # index = [0] * npts
+    index = None
     w = ll.LipIntValue( dim,npts,x,XData, YData,LipConst,index)
 
     # estimate Lipschitz constant
@@ -732,7 +735,8 @@ def test_smoothing():
     dim=4        # the dimension and size of the data set
     npts=200
     LipConst=4.0
-   
+    TData = [0.0] * npts
+    
     # arrays to store the data
     x, XData, YData = generate_random_data( dim, npts)
     for i in range( 0, npts): 
@@ -875,7 +879,7 @@ def test_STCInterpolant_smoothened_data_class():
 ###
 print( "-- test wrapper start --")
 
-test_case = 13
+test_case = 5
 
 if test_case == 1: initial_test() 
 elif test_case == 2: initial_test_class() 
